from ..base import BaseExporter
from ..utils import get_podman_names, get_podman_disk_target
from pathlib import Path

POSTFIX_QUEUES = ["active", "bounce", "deferred", "incoming", "maildrop"]

class CustomExporter(BaseExporter):
    def metric_config(self):
        return {
            "postfix_queue_size": {"type": "Gauge", "labels": ["machine", "queue"]},
            "postfix_queue_errors": {"type": "Gauge", "labels": ["machine"]},
        }

    def generate(self):
        pod_filter = None
        if len(self.args) >= 1:
            pod_filter = self.args[0]

        postfix_queue_size = self.metrics.get('postfix_queue_size')
        postfix_queue_errors = self.metrics.get('postfix_queue_errors')

        pod_names = get_podman_names(pod_filter)
        for pod in pod_names:
            target = get_podman_disk_target(pod, 'root')
            for queue in POSTFIX_QUEUES:
                path = Path("%s/%s/%s" % (target, "/var/spool/postfix/", queue))
                if path.exists():
                    postfix_queue_size.labels(pod, queue).set(sum(1 for _ in path.glob('*')))
                else:
                    postfix_queue_errors.labels(pod).inc()
