from ..base import BaseExporter
from ..utils import podman_batch_command, get_podman_names
import json

class CustomExporter(BaseExporter):
    def metric_config(self):
        return {
            "container_service_state": {"type": "Gauge", "labels": ["machine", "service"]},
            "container_service_errors": {"type": "Gauge", "labels": []},
        }

    def generate(self):
        if len(self.args) == 0:
            raise Exception("services (comma seperated) must be passed as first arg")

        pod_filter = None
        if len(self.args) >= 2:
             pod_filter = self.args[1]

        services = self.args[0].split(",")
        service_state = self.metrics.get('container_service_state')
        service_errors = self.metrics.get('container_service_errors')
        pod_names = get_podman_names(pod_filter)

        service_results = podman_batch_command(
            pool_size=5,
            pods=pod_names,
            command=["systemctl", "list-units", "-o", "json"]
        )
        for pod, sr in service_results.items():
            if sr.returncode == 0:
                sj = json.loads(sr.stdout)
                for service in services:
                    [unit] = [u for u in sj if u['unit'] == '%s.service' % service]
                    if unit and unit['active'] == 'active' and unit['sub'] == 'running':
                        service_state.labels(pod, service).set(1)
                    else:
                        service_state.labels(pod, service).set(0)
            else:
                service_errors.lables().inc()
